pub fn face_shape_occludes(
shape1: VoxelShape,
shape1_face: Direction,
shape2: VoxelShape,
shape2_face: Direction,
) -> boolExpand description
Checks whether two face occlusion shapes fully cover a block face.
pub fn face_shape_occludes(
shape1: VoxelShape,
shape1_face: Direction,
shape2: VoxelShape,
shape2_face: Direction,
) -> boolChecks whether two face occlusion shapes fully cover a block face.